package cn.yyxx.eyuangame.core.impl.center

import android.app.Dialog
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.text.InputType
import android.view.Gravity
import android.view.View
import android.view.Window
import android.view.WindowManager
import android.widget.Button
import android.widget.ImageView
import cn.yyxx.eyuangame.core.entity.ClickType
import cn.yyxx.eyuangame.core.entity.ResultInfo
import cn.yyxx.eyuangame.core.entity.SdkBackLoginInfo
import cn.yyxx.eyuangame.core.impl.SdkBridgeImpl
import cn.yyxx.eyuangame.core.internal.IImplCallback
import cn.yyxx.eyuangame.core.internal.IRequestCallback
import cn.yyxx.eyuangame.core.network.SdkRequest
import cn.yyxx.eyuangame.core.ui.EventEditText
import cn.yyxx.eyuangame.core.utils.EditTextUtils
import cn.yyxx.support.DensityUtils
import cn.yyxx.support.ResUtils
import cn.yyxx.support.hawkeye.ToastUtils
import org.json.JSONObject

/**
 * @author #Suyghur.
 * Created on 2021/12/23
 */
class BindAccountContainer(context: Context, private val callback: IImplCallback) : Dialog(context) {

    private lateinit var ivReturn: ImageView
    private lateinit var eetAccount: EventEditText
    private lateinit var eetPwd: EventEditText
    private lateinit var btnConfirm: Button

    private var imgShow = 0
    private var imgHide = 0
    private var isShowText = false

    init {
        setCanceledOnTouchOutside(true)
        window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        requestWindowFeature(Window.FEATURE_NO_TITLE)
        initView(context)
    }

    private fun initView(context: Context) {
        setContentView(ResUtils.getResId(context, "yyxx_member_bind_account", "layout"))

        val attr = window?.attributes as WindowManager.LayoutParams
        attr.height = DensityUtils.dip2px(context, 250f)
        if (SdkBridgeImpl.isLand) {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] / 2
        } else {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] - 80
        }
        attr.gravity = Gravity.CENTER

        imgShow = ResUtils.getResId(context, "yyxx_show_img", "drawable")
        imgHide = ResUtils.getResId(context, "yyxx_hide_img", "drawable")

        ivReturn = findViewById(ResUtils.getResId(context, "yyxx_iv_return", "id"))
        ivReturn.apply {
            tag = ClickType.ACTION_RETURN
            setOnClickListener {
                dismiss()
            }
        }

        eetAccount = findViewById(ResUtils.getResId(context, "yyxx_eet_account", "id"))
        eetAccount.apply {
            leftImageView.setBackgroundResource(ResUtils.getResId(context, "yyxx_account_img", "drawable"))
            leftImageView.visibility = View.VISIBLE
            rightImageView.visibility = View.GONE
            editText.setHint(ResUtils.getResId(context, "yyxx_hint_bind_account_uname", "string"))
        }

        eetPwd = findViewById(ResUtils.getResId(context, "yyxx_eet_pwd", "id"))
        eetPwd.apply {
            editText.inputType = InputType.TYPE_TEXT_VARIATION_PASSWORD or InputType.TYPE_CLASS_TEXT
            leftImageView.setBackgroundResource(ResUtils.getResId(context, "yyxx_pwd_img", "drawable"))
            leftImageView.visibility = View.VISIBLE
            editText.setHint(ResUtils.getResId(context, "yyxx_hint_bind_account_pwd", "string"))
            rightImageView.setBackgroundResource(imgShow)
            rightImageView.visibility = View.VISIBLE
            rightImageView.setOnClickListener {
                if (!isShowText) {
                    isShowText = true
                    rightImageView.setBackgroundResource(imgHide)
                    editText.inputType = InputType.TYPE_TEXT_VARIATION_VISIBLE_PASSWORD
                } else {
                    isShowText = false
                    rightImageView.setBackgroundResource(imgShow)
                    editText.inputType = InputType.TYPE_TEXT_VARIATION_PASSWORD or InputType.TYPE_CLASS_TEXT
                }
                editText.setSelection(editText.length())
            }
        }

        btnConfirm = findViewById(ResUtils.getResId(context, "yyxx_btn_confirm", "id"))
        btnConfirm.apply {
            setOnClickListener {
                callBindAccount()
            }
        }
    }

    private fun callBindAccount() {
        val userName = eetAccount.editText.text.trim().toString()
        val pwd = eetPwd.editText.text.trim().toString()

        if (!EditTextUtils.filterAccount(userName)) {
            ToastUtils.toastInfo(context, ResUtils.getResString(context, "yyxx_tips_account_format_error"))
            return
        }
        if (!EditTextUtils.filterPwd(pwd)) {
            ToastUtils.toastInfo(context, ResUtils.getResString(context, "yyxx_tips_pwd_format_error"))
            return
        }

        try {
            with(JSONObject()) {
                put("uid", SdkBackLoginInfo.instance.userId)
                put("login_type", SdkBackLoginInfo.instance.loginType)
                put("uname", userName)
                put("pwd", pwd)
                SdkRequest.instance.bindAccount(context, this, object : IRequestCallback {
                    override fun onResponse(resultInfo: ResultInfo) {
                        if (resultInfo.code == 1) {
                            SdkBackLoginInfo.instance.hasBindAccount = true
                            ToastUtils.toastInfo(context, resultInfo.msg)
                            callback.onResult(0, resultInfo.msg)
                            dismiss()
                        } else {
                            ToastUtils.toastInfo(context, resultInfo.msg)
                        }
                    }
                })
            }
        } catch (e: Exception) {
            e.printStackTrace()
        }

    }
}