package cn.yyxx.eyuangame.core.impl.center

import android.app.Dialog
import android.content.Context
import android.graphics.Color
import android.graphics.drawable.ColorDrawable
import android.text.TextUtils
import android.view.Gravity
import android.view.View
import android.view.Window
import android.view.WindowManager
import android.widget.ImageView
import android.widget.TextView
import androidx.constraintlayout.widget.ConstraintLayout
import cn.yyxx.eyuangame.core.entity.LoginType
import cn.yyxx.eyuangame.core.entity.SdkBackLoginInfo
import cn.yyxx.eyuangame.core.impl.SdkBridgeImpl
import cn.yyxx.eyuangame.core.internal.IImplCallback
import cn.yyxx.support.DensityUtils
import cn.yyxx.support.ResUtils

/**
 * @author #Suyghur.
 * Created on 2021/12/23
 */
class MemberCenterContainer(context: Context) : Dialog(context) {

    private lateinit var ivReturn: ImageView
    private lateinit var clBindAccount: ConstraintLayout
    private lateinit var clBindPhone: ConstraintLayout
    private lateinit var clModifyPwd: ConstraintLayout

    private lateinit var ivAccountIcon: ImageView
    private lateinit var tvAccountTips: TextView

    private var bindAccountContainer: BindAccountContainer? = null
    private var bindPhoneContainer: BindPhoneContainer? = null
    private var modifyPwdContainer: ModifyPwdContainer? = null


    init {
        setCanceledOnTouchOutside(true)
        window?.setBackgroundDrawable(ColorDrawable(Color.TRANSPARENT))
        requestWindowFeature(Window.FEATURE_NO_TITLE)
        initView(context)
    }

    private fun initView(context: Context) {
        setContentView(ResUtils.getResId(context, "yyxx_member_center", "layout"))

        val attr = window?.attributes as WindowManager.LayoutParams
        attr.height = DensityUtils.dip2px(context, 250f)
        if (SdkBridgeImpl.isLand) {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] / 2
        } else {
            attr.width = DensityUtils.getHeightAndWidth(context)[0] - 80
        }
        attr.gravity = Gravity.CENTER

        ivReturn = findViewById(ResUtils.getResId(context, "yyxx_iv_return", "id"))
        ivReturn.setOnClickListener {
            dismiss()
        }


        clBindAccount = findViewById(ResUtils.getResId(context, "yyxx_cl_bind_account", "id"))
        clBindAccount.setOnClickListener {
            bindAccountContainer?.apply {
                dismiss()
                bindAccountContainer = null
            }
            bindAccountContainer = BindAccountContainer(context, object : IImplCallback {
                override fun onResult(code: Int, result: String) {
                    if (code == 0) {
                        showOrHideBindAccount()
                        showOrHideBindPhone()
                        showOrHideModifyPwd()
                    }
                }
            })
            bindAccountContainer?.show()
        }
        clBindPhone = findViewById(ResUtils.getResId(context, "yyxx_cl_bind_phone", "id"))
        clBindPhone.setOnClickListener {
            bindPhoneContainer?.apply {
                dismiss()
                bindPhoneContainer = null
            }
            bindPhoneContainer = BindPhoneContainer(context, object : IImplCallback {
                override fun onResult(code: Int, result: String) {
                    if (code == 0) {
                        showOrHideBindAccount()
                        showOrHideBindPhone()
                        showOrHideModifyPwd()
                    }
                }
            })
            bindPhoneContainer?.show()
        }

        clModifyPwd = findViewById(ResUtils.getResId(context, "yyxx_cl_modify_pwd", "id"))
        clModifyPwd.setOnClickListener {
            modifyPwdContainer?.apply {
                dismiss()
                modifyPwdContainer = null
            }
            modifyPwdContainer = ModifyPwdContainer(context)
            modifyPwdContainer?.show()
        }

        ivAccountIcon = findViewById(ResUtils.getResId(context, "yyxx_iv_bind_account_icon", "id"))
        tvAccountTips = findViewById(ResUtils.getResId(context, "yyxx_tv_bind_account_tips", "id"))
        var img = 0
        var tips = ""
        when (SdkBackLoginInfo.instance.loginType) {
            LoginType.TYPE_GUEST_LOGIN -> {
                img = ResUtils.getResId(context, "yyxx_guest_img", "drawable")
                tips = ResUtils.getResString(context, "yyxx_login_type_guest")
            }
            LoginType.TYPE_FACEBOOK_LOGIN -> {
                img = ResUtils.getResId(context, "yyxx_facebook_img", "drawable")
                tips = ResUtils.getResString(context, "yyxx_login_type_facebook")
            }
            LoginType.TYPE_GOOGLE_LOGIN -> {
                img = ResUtils.getResId(context, "yyxx_google_img", "drawable")
                tips = ResUtils.getResString(context, "yyxx_login_type_google")
            }
        }
        ivAccountIcon.setBackgroundResource(img)
        tvAccountTips.text = tips

        showOrHideBindAccount()
        showOrHideBindPhone()
        showOrHideModifyPwd()
    }

    private fun showOrHideBindAccount() {
        clBindAccount.visibility = if (SdkBackLoginInfo.instance.hasBindAccount) {
            View.GONE
        } else {
            View.VISIBLE
        }
    }

    private fun showOrHideBindPhone() {
        clBindPhone.visibility = if (SdkBackLoginInfo.instance.hasBindAccount) {
            View.VISIBLE
        } else {
            View.GONE
        }
    }

    private fun showOrHideModifyPwd() {
        clModifyPwd.visibility = if (SdkBackLoginInfo.instance.hasBindAccount && !TextUtils.isEmpty(SdkBackLoginInfo.instance.phoneNum)) {
            View.VISIBLE
        } else {
            View.GONE
        }
    }
}